## 0.2.12 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 0.2.11 (2022-03-10)

Modernize syntax in various stubs (#7469)

Use `str` and `contextlib.AbstractContextManager` instead of `typing.Text` and `typing.ContextManager`.

## 0.2.10 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.2.9 (2022-01-16)

Cleanup: do not quote types unnecessarily (#6931)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 0.2.8 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.2.6 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 0.2.5 (2021-10-12)

Add star to all non-0.1 versions (#6146)

